@@ -2,7 +2,7 @@ import argparse
 import os
 from .transcribe import Transcribe, TranscriptionOptions
 from .models import Models
-from .languages import LANGUAGES, TO_LANGUAGE_CODE
+from .languages import LANGUAGES, TO_LANGUAGE_CODE, from_language_to_iso_code
 import numpy as np
 import warnings
 from typing import Union
@@ -185,6 +185,20 @@ def read_command_line():
         "--device", default="auto", help="device to use for CTranslate2 inference"
     )
 
+    parser.add_argument(
+        "--vad_filter",
+        type=bool,
+        default=False,
+        help="Enable the voice activity detection (VAD) to filter out parts of the audio without speech. This step is using the Silero VAD model https://github.com/snakers4/silero-vad.",
+    )
+
+    parser.add_argument(
+        "--vad_min_silence_duration_ms",
+        type=int,
+        default=2000,
+        help="When `vad_filter` is enabled, audio segments without speech for at least this number of milliseconds will be ignored.",
+    )
+
     # CTranslate2 specific parameters
     parser.add_argument(
         "--device_index",
@@ -226,16 +240,6 @@ def read_command_line():
     return parser.parse_args().__dict__
 
 
-def _from_language_to_iso_code(language):
-    if language is not None:
-        language_name = language.lower()
-        if language_name not in LANGUAGES:
-            if language_name in TO_LANGUAGE_CODE:
-                language = TO_LANGUAGE_CODE[language_name]
-
-    return language
-
-
 def main():
     args = read_command_line()
     output_dir: str = args.pop("output_dir")
@@ -259,7 +263,7 @@ def main():
     else:
         temperature = [temperature]
 
-    language = _from_language_to_iso_code(language)
+    language = from_language_to_iso_code(language)
 
     if (
         not model_directory
@@ -284,15 +288,13 @@ def main():
         condition_on_previous_text=args.pop("condition_on_previous_text"),
         temperature=temperature,
         initial_prompt=args.pop("initial_prompt"),
-        #        prefix = None,
-        #        suppress_blank = None,
         suppress_tokens=suppress_tokens,
-        #        without_timestamps = None,
-        #        max_initial_timestamp =  None,
         word_timestamps=args.pop("word_timestamps"),
         prepend_punctuations=args.pop("prepend_punctuations"),
         append_punctuations=args.pop("append_punctuations"),
         print_colors=args.pop("print_colors"),
+        vad_filter=args.pop("vad_filter"),
+        vad_min_silence_duration_ms=args.pop("vad_min_silence_duration_ms"),
     )
 
     if verbose:
